class Converter:
    def __init__(self, basename, outname=None):
        self.basename = basename
        self.outname = outname

    def convert(self):
        pass
